﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Controls;

namespace Demo.Controls
{
	public class FilterDemoFilterItem : Control
	{
		public FilterDemoFilterItem()
		{
			this.DefaultStyleKey = typeof(FilterDemoFilterItem);
		}

		public override void OnApplyTemplate()
		{
			base.OnApplyTemplate();
			m_dropDownElement = GetTemplateChild("dropDownElement") as ComboBox;
			if ((m_dropDownElement != null) && (m_firstItemSelectable))
				m_dropDownElement.SelectedIndex = 0;
		}

		public static readonly DependencyProperty LabelProperty =
			DependencyProperty.Register("Label", typeof(string), typeof(FilterDemoFilterItem), new PropertyMetadata(default(string)));

		public string Label
		{
			get { return (string)GetValue(LabelProperty); }
			set { SetValue(LabelProperty, value); }
		}

		public static readonly DependencyProperty DividerProperty =
			DependencyProperty.Register("Divider", typeof(string), typeof(FilterDemoFilterItem), new PropertyMetadata(default(string)));

		public string Divider
		{
			get { return (string)GetValue(DividerProperty); }
			set { SetValue(DividerProperty, value); }
		}


		public static readonly DependencyProperty SuffixProperty =
			DependencyProperty.Register("Suffix", typeof(string), typeof(FilterDemoFilterItem), new PropertyMetadata(default(string)));

		public string Suffix
		{
			get { return (string)GetValue(SuffixProperty); }
			set { SetValue(SuffixProperty, value); }
		}


		public static readonly DependencyProperty FilterItemsProperty =
			DependencyProperty.Register("FilterItems", typeof(IList<string>), typeof(FilterDemoFilterItem),
				new PropertyMetadata(default(ObservableCollection<string>), (d, e) => ((FilterDemoFilterItem)d).HandleFilterItemsChanged(e.NewValue as IList<string>)));

		public IList<string> FilterItems
		{
			get { return (ObservableCollection<string>)GetValue(FilterItemsProperty); }
			set { SetValue(FilterItemsProperty, value); }
		}

		private bool m_firstItemSelectable;

		private void HandleFilterItemsChanged(IList<string> items)
		{
			m_firstItemSelectable = ((items != null) && (items.Count > 0));
			if ((m_dropDownElement != null) && (m_firstItemSelectable))
				m_dropDownElement.SelectedIndex = 0;
		}


		public static readonly DependencyProperty DropDownStyleProperty =
			DependencyProperty.Register("DropDownStyle", typeof(Style), typeof(FilterDemoFilterItem), new PropertyMetadata(default(Style)));

		private ComboBox m_dropDownElement;

		public Style DropDownStyle
		{
			get { return (Style)GetValue(DropDownStyleProperty); }
			set { SetValue(DropDownStyleProperty, value); }
		}

	}
}
