﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;

namespace Demo.Controls
{
	public class ProgressiveDisclosureLink : HeaderedContentControl
	{
		private ButtonBase m_triggerElement;
		private ContentPresenter m_contentPresenter;

		public ProgressiveDisclosureLink()
		{
			this.DefaultStyleKey = typeof( ProgressiveDisclosureLink );
		}

		public static readonly DependencyProperty HeaderMarginProperty =
			DependencyProperty.Register( "HeaderMargin", typeof( Thickness ), typeof( ProgressiveDisclosureLink ), new PropertyMetadata( default( Thickness ) ) );

		public Thickness HeaderMargin
		{
			get { return (Thickness) GetValue( HeaderMarginProperty ); }
			set { SetValue( HeaderMarginProperty, value ); }
		}

		public override void OnApplyTemplate()
		{
			base.OnApplyTemplate();
			m_triggerElement = GetTemplateChild( "ExpandTriggerElement" ) as ButtonBase;
			m_contentPresenter = GetTemplateChild( "ContentPresenterElement" ) as ContentPresenter;

			if (m_triggerElement != null)
				m_triggerElement.Click += HandleTriggerClick;
		}

		private void HandleTriggerClick( object sender, RoutedEventArgs e )
		{
			if (m_triggerElement != null)
				m_triggerElement.Visibility = Visibility.Collapsed;
			if (m_contentPresenter != null)
				m_contentPresenter.Visibility = Visibility.Visible;
#if TBR
			var firstControl = FindFirstControl(m_contentPresenter.Content);
			if (firstControl != null)
				firstControl.Focus();
#endif
		}

#if TBR
		private Control FindFirstControl(object parent)
		{
			var parentDependencyObject = parent as DependencyObject;
			if (parentDependencyObject == null)
				return null;
			return FindFirstControl(parentDependencyObject);
		}

		private Control FindFirstControl(DependencyObject parent)
		{
			var children = parent.GetVisualChildren().ToArray();
			var firstControl = children.Where(child => child is Control).Select(child => (Control)child).FirstOrDefault(childControl => childControl.Visibility == Visibility.Visible);
			if (firstControl != null)
				return firstControl;
			foreach (var child in children)
			{
				firstControl = FindFirstControl(child);
				if (firstControl != null)
					return firstControl;
			}
			return null;
		}
#endif
	}
}
