﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using System.Windows.Resources;
using System.Xml.Linq;

namespace Demo
{
	public partial class MainPage : UserControl
	{
		private INavigationService m_navigationService;

		public MainPage()
		{
			InitializeComponent();
			this.Loaded += (s, e) =>
							{
								m_navigationService = new FrameNavigationService(contentFrame);
								m_navigationService.NavigationFailed += HandleNavigationFailed;

								MainModel model = new MainModel { Navigation = m_navigationService };

								var pageInfos = DiscoverPages();
								model.PageInfos = new ObservableCollection<PageInfo>(pageInfos);
								this.DataContext = model;
							};
		}

		private IEnumerable<PageInfo> DiscoverPages()
		{
			StreamResourceInfo sr = Application.GetResourceStream(new Uri("Pages/_Index.xml", UriKind.Relative));
			XDocument document = XDocument.Load(sr.Stream);
			var pagesTag = document.Element("Pages");
			if (pagesTag == null)
				throw new Exception("Missing <Pages> tag");

			var pageInfos = from pageTag in pagesTag.Descendants("Page")
							select new PageInfo
								{
									DisplayName = GetAttributeValue(pageTag, "title"),
									Uri = new Uri("/" + GetAttributeValue(pageTag, "name"), UriKind.Relative)
								};
			return pageInfos;
		}

		private string GetAttributeValue(XElement tag, string attributeName)
		{
			var attribute = tag.Attribute(attributeName);
			return attribute != null ? attribute.Value : String.Empty;
		}

		void HandleNavigationFailed(object sender, NavigationFailedEventArgs e)
		{
			Exception ex = e.Exception;

			while (ex.InnerException != null)
			{
				ex = ex.InnerException;
			}

			e.Handled = true;
			ChildWindow errorWin = new ErrorWindow(ex);
			errorWin.Show();

		}
	}
}