using System;
using System.ComponentModel;
using System.Linq.Expressions;

namespace Demo
{
	public class ViewModel : INotifyPropertyChanged
	{
		protected void UpdateValue<T>(Expression<Func<T>> expression, ref T property, T value, Action propertyChangedAction=null)
		{
			if (Object.Equals(property, value))
				return;

			var propertyName = NameHelper.GetName(expression);

			property = value;
			if (propertyChangedAction != null)
				propertyChangedAction();

			RaisePropertyChanged(propertyName);
		}

		private void RaisePropertyChanged(string propertyName)
		{
			var handler = PropertyChanged;
			if (handler != null)
				handler(this, new PropertyChangedEventArgs(propertyName));
		}

		public event PropertyChangedEventHandler PropertyChanged;
	}
}